@@ -4,12 +4,11 @@ import { IDocumentManager } from '@jupyterlab/docmanager';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { SETTINGS_ID, getTransformerEnabled } from './settings';
 import { CellMetadataEditor, IProps as EditorProps } from './widgets/CellMetadataEditor';
-import { Cell, isCodeCellModel, isRawCellModel } from '@jupyterlab/cells';
+import { Cell, ICellModel, isCodeCellModel, isRawCellModel } from '@jupyterlab/cells';
 import * as React from 'react';
 import * as ReactDOM from 'react-dom';
 import TagsUtils from './lib/TagsUtils';
 import { IObservableList, IObservableUndoableList } from '@jupyterlab/observables';
-import { ICellModel } from '@jupyterlab/cells';
 import NotebookUtils from './lib/NotebookUtils';
 import { PageConfig } from '@jupyterlab/coreutils';
 
@@ -23,6 +22,13 @@ export const getTransformerNotebookDirectory = (): string => {
 
 let editors: EditorProps[] = [];
 let isTransformerEnabled: boolean;
+let transformerNotebookPanel: NotebookPanel = null;
+export const saveTransformerNotebook = async () => {
+    if(transformerNotebookPanel) {
+        await transformerNotebookPanel.context.ready;
+        await transformerNotebookPanel.context.save();
+    }
+}
 const handleNotebookChanged = async (notebookTracker: INotebookTracker, notebookPanel: NotebookPanel) => {
     if (notebookPanel.title.label == TRANSFORMER_NB_FILE_NAME) {
         console.log("Now " + TRANSFORMER_NB_FILE_NAME + "...");
@@ -55,6 +61,7 @@ const handleNotebookChanged = async (notebookTracker: INotebookTracker, notebook
             console.warn(e);
             transformer_notebook_path = PageConfig.getOption('serverRoot') + '/' + notebookPanel.context.path;
         }
+        transformerNotebookPanel = notebookPanel;
     }
 }
 
