@@ -7,7 +7,7 @@ import { Kernel } from '@jupyterlab/services';
 import { Switch } from '@material-ui/core';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { getTransformerEnabled, setTransformerEnabled, getTransformerProxyUrl } from './../settings';
-import { getTransformerNotebookDirectory } from './../notebook';
+import { getTransformerNotebookDirectory, saveTransformerNotebook } from './../notebook';
 import { Button, Dialog, DialogActions, DialogContent, DialogTitle } from '@material-ui/core';
 
 interface IProps {
@@ -97,11 +97,23 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
 
     applyTransformerToProxy = async () => {
         console.log('applyTransformerToProxy');
+        this.renderDialog({
+            title: 'Info',
+            content: 'This will save the changes and apply them to proxy!',
+            isCloseButtonVisible: true,
+            closeButtonText: 'Cancel',
+            isConfirmButtonVisible: true
+        });
+        this.setState({ dialogConfirmClickHandler: this.doApplyTransformer });
+    };
+
+    doApplyTransformer = async () => {
         this.renderDialog({
             title: 'Running',
-            content: 'It will take few seconds!',
+            content: 'This will take few seconds!',
             isCloseButtonVisible: false
         });
+        saveTransformerNotebook();
 
         let proxyUrl: string = getTransformerProxyUrl();
         if(! proxyUrl) {
@@ -109,6 +121,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
                 title: 'Error',
                 content: 'Unable to get the proxy URL!'
             });
+            this.setState({ dialogConfirmClickHandler: this.onDialogConfirmClick });
             return;
         }
 
@@ -132,13 +145,14 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
             });
             throw error;
         }
+        this.setState({ dialogConfirmClickHandler: this.onDialogConfirmClick });
     };
 
     resetTransformer = () => {
         console.log('resetTransformer');
         this.renderDialog({
             title: 'Warning',
-            content: 'It will reset transformer.ipynb and you may lose your customized content!',
+            content: 'This will reset transformer.ipynb and you may lose your code!',
             closeButtonText: 'Cancel',
             isConfirmButtonVisible: true
         });
@@ -160,7 +174,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
         try {
             this.renderDialog({
                 title: 'Running',
-                content: 'It will take few seconds!'
+                content: 'This will take few seconds!'
             });
             const kernel: Kernel.IKernelConnection = await NotebookUtils.createNewKernel();
             const args = {
